mdbook-github-authors
This crate produces a preprocessor for the rust-lang mdbook project that lists authors via their Github profiles in a Contributor section appended to the bottom of a Chapter.
Basic Usage
First, install the crate:
cargo install mdbook-github-authorsNext, and as with all preprocessor extensions, to include mdbook-github-authors
in your book, add the following to your book.toml:
[preprocessor.github-authors]
command = "mdbook-github-authors"In order to add an author or list of authors in your chapter, there are two supported helpers:
<!-- for single author -->
{{#author <github-username>}}
<!-- for multiple authors -->
{{#authors <comma-separated-list-of-usernames>>}}For more details see the project’s README
Re-exports
pub use github_authors::GithubAuthorsPreprocessor;